package com.jiuqi.grid;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.jiuqi.grid.CellDataProcessorIntf;
import com.jiuqi.grid.CellDataProperty;
import com.jiuqi.grid.CellDataPropertyIntf;
import com.jiuqi.grid.CurrencyCellPropertyIntf;
import com.jiuqi.grid.GridCell;
import com.jiuqi.grid.NumberCellProperty;
import java.io.Serializable;

public final class CurrencyCellProperty extends NumberCellProperty implements CurrencyCellPropertyIntf, CellDataProcessorIntf, Serializable {
  public static final String[] CURRENCY_UNIT_NAMES = new String[] { "", "CNY", "USD", "EUR", "JPY", "HKD", "GBP", "CHF", "SUR", "CAD" };
  
  public static final String[] CURRENCY_UNIT_TITLES = new String[] { "", "人民币元", "美元", "欧元", "日圆", "港元", "英镑", "瑞士法郎", "俄罗斯卢布", "加拿大元" };
  
  public static final String[] CURRENCY_UNIT_SIGNS = new String[] { "", "￥", "＄", "EUR", "J.￥", "HK＄", "￡", "SF.", "Rbs.", "Can.＄" };
  
  public CurrencyCellProperty(GridCell cell) {
    this((CellDataPropertyIntf)new CellDataProperty(cell));
  }
  
  public CurrencyCellProperty(CellDataPropertyIntf dataProperty) {
    super(dataProperty);
  }
  
  public int getUnitIndex() {
    int dataFormat = this.cellDataProperty.getDataFormat();
    return dataFormat & 0xF;
  }
  
  public void setUnitIndex(int value) {
    if (value < 0 || value >= 10)
      throw new IllegalArgumentException("货币符号被错误设置,只能在0-9之间!"); 
    this.cellDataProperty.setDataFormat((byte)value);
  }
  
  public int getUnitShowType() {
    return (this.cellDataProperty.getDataProperty() & 0x300) >> 8;
  }
  
  public void setUnitShowType(int value) {
    if (value < 0 || value > 3)
      throw new IllegalArgumentException("显示类型被错误设置,应该被设置到0-3之间!"); 
    value &= 0x3;
    this.cellDataProperty.setDataProPerty(
        (short)(this.cellDataProperty.getDataProperty() & 0xFFFFFCFF | value << 8));
  }
  
  public String getUnitTitle() {
    return CURRENCY_UNIT_TITLES[getUnitIndex()];
  }
  
  public void setUnitTitle(String value) {
    int i = 0;
    boolean found = false;
    while (!found) {
      if (value.equals(CURRENCY_UNIT_TITLES[i])) {
        found = true;
        break;
      } 
      i++;
    } 
    if (found) {
      setUnitIndex(i);
    } else {
      throw new IllegalArgumentException("没有这样的货币单位!");
    } 
  }
  
  public boolean getShowCurrencyBox() {
    if (this.cellDataProperty.getDataType() == 3)
      return ((this.cellDataProperty.getDataProperty() & 0x400) != 0); 
    return false;
  }
  
  public void setShowCurrencyBox(boolean value) {
    if (this.cellDataProperty.getDataType() == 3)
      if (value) {
        this.cellDataProperty.setDataProPerty(
            
            (short)(this.cellDataProperty.getDataProperty() | 0x400));
      } else {
        this.cellDataProperty.setDataProPerty(
            
            (short)(this.cellDataProperty.getDataProperty() & 0xFFFFFBFF));
      }  
  }
  
  public String getUnitString() {
    return CURRENCY_UNIT_SIGNS[getUnitIndex()];
  }
  
  public String getShowText(String storeText) {
    String showText = super.getShowText(storeText);
    int unitIndex = getUnitIndex();
    if (unitIndex >= 0) {
      int unitShowType = getUnitShowType();
      switch (unitShowType) {
        case 0:
          showText = String.valueOf(CURRENCY_UNIT_SIGNS[unitIndex]) + " " + showText;
          break;
        case 1:
          showText = String.valueOf(CURRENCY_UNIT_NAMES[unitIndex]) + " " + showText;
          break;
        case 2:
          showText = String.valueOf(showText) + " " + CURRENCY_UNIT_NAMES[unitIndex];
          break;
        case 3:
          showText = String.valueOf(CURRENCY_UNIT_TITLES[unitIndex]) + " " + showText;
          break;
      } 
    } 
    return showText;
  }
  
  public String parseShowText(String showText) {
    String number = null;
    int unitIndex = getUnitIndex();
    int unitShowType = getUnitShowType();
    String unitAdd = null;
    switch (unitShowType) {
      case 0:
        unitAdd = CURRENCY_UNIT_SIGNS[unitIndex];
        if (showText.startsWith(unitAdd)) {
          number = showText.substring(unitAdd.length());
        } else {
          throw new IllegalArgumentException("开头的货币符号和定义的货币符号不符！");
        } 
        return super.parseShowText(number);
      case 1:
        unitAdd = CURRENCY_UNIT_NAMES[unitIndex];
        if (showText.startsWith(unitAdd)) {
          number = showText.substring(unitAdd.length());
        } else {
          throw new IllegalArgumentException("开头的货币英文缩写和定义的货币符号不符！");
        } 
        return super.parseShowText(number);
      case 2:
        unitAdd = CURRENCY_UNIT_NAMES[unitIndex];
        if (showText.endsWith(unitAdd)) {
          number = showText.substring(0, showText.length() - unitAdd.length());
        } else {
          throw new IllegalArgumentException("尾部的货币英文缩写和定义的货币符号不符！");
        } 
        return super.parseShowText(number);
      case 3:
        unitAdd = CURRENCY_UNIT_TITLES[unitIndex];
        if (showText.endsWith(unitAdd)) {
          number = showText.substring(0, showText.length() - unitAdd.length());
        } else {
          throw new IllegalArgumentException("尾部的货币名称和定义的货币符号不符！");
        } 
        return super.parseShowText(number);
    } 
    number = showText;
    return super.parseShowText(number);
  }
}
